/***************************************************************************
 *   Copyright (C) 2004 by Antonio Fasolato                                *
 *   neo@localhost                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "convertpage.h"

#include <qradiobutton.h>
#include <qbuttongroup.h>
#include <qcheckbox.h>
#include <qslider.h>

#include <kfiledialog.h>
#include <klocale.h>
#include <kcombobox.h>
#include <klineedit.h>
#include <kmessagebox.h>

ConvertPage::ConvertPage(QWidget* parent, const char* name, WFlags fl): ConvertPageBase(parent,name,fl), options(new Options()) {
	connect(this,SIGNAL(optionsChanged()),this,SLOT(parseOptions()));
}

ConvertPage::~ConvertPage() {
}

void ConvertPage::outputChosen() {
  emit optionsChanged();
}

void ConvertPage::formatChosen() {
  if(formatCombo->currentText()=="mp3") {
	  options->setFormat(mp3);
	  bitrateGroup->setEnabled(true);
	  mp3HeaderGroup->setEnabled(true);
	  modeCombo->setEnabled(true);
	  qualityGroup->setEnabled(false);
	  if(modeCombo->currentText()=="Mono")
	  	downmixCheck->setEnabled(true);
	  newVbrCheck->setEnabled(true);
  }
  else if(formatCombo->currentText()=="ogg") {
	  options->setFormat(ogg);
	  bitrateGroup->setEnabled(false);
	  mp3HeaderGroup->setEnabled(false);
	  qualityGroup->setEnabled(true);
	  modeCombo->setEnabled(true);
	  if(modeCombo->currentText()=="Mono")
	  	downmixCheck->setEnabled(true);
	  newVbrCheck->setEnabled(false);
  }
  else {   //wav
	  options->setFormat(wav); 
	  bitrateGroup->setEnabled(false);
	  mp3HeaderGroup->setEnabled(false);
	  modeCombo->setEnabled(false);
	  qualityGroup->setEnabled(false);
	  downmixCheck->setEnabled(false);
	  newVbrCheck->setEnabled(false);
  }
  
  emit optionsChanged();
}

void ConvertPage::clearSelection() {
	for(int i=fileSelectionList->count(); i>-1; i--) {
		delete fileSelectionList->item(i);
	}
  
	options->setSourceDir("");
}

void ConvertPage::addFile() {
	QStringList l;
	l=KFileDialog::getOpenFileNames("",i18n("*.mp3 *.ogg *.wav|All supported formats\n*.mp3|mp3 audio file\n*.ogg|ogg Vorbis audio file\n*.wav|wave audio file"),this,i18n("Select the files to be converted"));
  
	QStringList pruned;
	for(QStringList::Iterator i=l.begin(); i!=l.end(); ++i) {
		if(!(QFileInfo(*i).isDir()))
			pruned+=*i;
	}
	
  	//reading source dir
	if(options->getSourceDir()=="") {
		QFileInfo info(pruned[0]);
		options->setSourceDir(info.dirPath());
		emit optionsChanged();
	}

	fileSelectionList->insertStringList(pruned,-1);
}

void ConvertPage::deleteFile() {
  for(int i=fileSelectionList->count(); i>-1; i--) {
	  if(fileSelectionList->isSelected(i)) {
		  delete fileSelectionList->item(i);
	  }
  }
  
  if(fileSelectionList->count()==0) //no more files
	  options->setSourceDir("");
}

void ConvertPage::addDir() {
// 	QString dirName=KFileDialog::getExistingDirectory("",this,i18n("Select the directory that contains your files"));
// 	if(dirName) {
// 		QStringList l=traverse(dirName);
// 	
// 		if(options->getSourceDir()=="") {
// 			QFileInfo info(l[0]);
// 			options->setSourceDir(info.dirPath());
// 			emit optionsChanged();
// 		}
// 
// 		fileSelectionList->insertStringList(l,-1);
// 	}	
	KMessageBox::sorry(this,i18n("Sorry, this isn't working at the moment"),i18n("Not implemented, yet"));
}

void ConvertPage::parseOptions( ) {
	//Sourcedir settings
	if(options->getSourceDir()!="") {
		if(outputGroup->selectedId()==0)  //same as input
			outputLine->setText(options->getSourceDir());
		else if(outputGroup->selectedId()==1) {  //subdirectory
			switch(options->getFormat()) {
				case wav:
					outputLine->setText(options->getSourceDir()+"/wav");
					break;
				case mp3:
					outputLine->setText(options->getSourceDir()+"/mp3");
					break;
				case ogg:
					outputLine->setText(options->getSourceDir()+"/ogg");
					break;
			}
		}
	}
			
	//check for format changes
	if(options->getFormat()==wav) {
		subdirRadio->setText(i18n("Subdirectory wav"));
	}
	if(options->getFormat()==mp3) {
		subdirRadio->setText(i18n("Subdirectory mp3"));
	}
	if(options->getFormat()==ogg) {
		subdirRadio->setText(i18n("Subdirectory ogg"));
	}
}

void ConvertPage::modeChosen(const QString& t) {
	if(t=="Mono")
		downmixCheck->setEnabled(true);
	else
		downmixCheck->setEnabled(false);
}

/** Executed just before leaving the page. A return value equal to false makes mainWidget not to change page
 */
bool ConvertPage::readOptions( ) {
	bool ok=true;
	
	if(fileSelectionList->count()==0) {
		KMessageBox::sorry(this,i18n("Sorry, you have to choose at least one file to convert"),i18n("No file selected"));
		ok=false;
	}
	else {
		//Reading options. Note that format and sourcedir have been stored previously.
		
		//File list
		QStringList fileList;
		for(uint i=0; i<fileSelectionList->count(); i++)
			fileList+=fileSelectionList->text(i);
		options->setFileList(fileList);
		
		//Output Dir
		QDir outputInfo(outputLine->text());
		if(outputInfo.exists())
			options->setOutputDir(outputLine->text());
		else {  //output dir not existing
			int answer=KMessageBox::questionYesNo(this,i18n("The output dir doesn't exist. Would you like to create it?"), i18n("Create dir?"));
			if(answer==KMessageBox::Yes) {
				if(!outputInfo.mkdir(outputLine->text(),true)) {
					KMessageBox::sorry(this,i18n("Sorry, cannot create output directory (%s)",outputLine->text()),i18n("Cannot create directory"));
					return false;
				}
				options->setOutputDir(outputLine->text());
			}
			else {
				return false;
			}
		}
		
		if(options->getFormat()==mp3) {
			//Bitrate (0=choose, 1=average, 2=variable, 3=preset)
			switch (bitrateGroup->selectedId()) {
				case 0:
					options->setBitrate(choose);
					options->setBitrateValue(bitrateCustomCombo->currentText().toInt());
					break;
				case 1:
					options->setBitrate(average);
					options->setBitrateValue(bitrateAverageCombo->currentText().toInt());
					break;
				case 2:
					options->setBitrate(variable);
					options->setBitrateValue(bitrateVariableCombo->currentText().toInt());
					break;
				case 3:
					options->setBitrate(preset);
					QString quality=bitratePresetCombo->currentText();
					if(quality=="Medium")
						options->setBitrateValue(0);  //medium
					else if(quality=="Standard")
						options->setBitrateValue(1);   //standard
					else if(quality=="Extreme")
						options->setBitrateValue(2);  //extreme
					else
						options->setBitrateValue(3);   //insane
					break;
			}
		}
		else if(options->getFormat()==ogg) {
			options->setBitrateValue(qualitySlider->value());
		}
		
		//mp3 header
		if(options->getFormat()==mp3) {
			options->setHeader(Options::OPTION_COPYRIGHT,copyrightCheck->isChecked());
			options->setHeader(Options::OPTION_ORIGINAL,originalCheck->isChecked());
			options->setHeader(Options::OPTION_ERROR_PROTECTION,protectionCheck->isChecked());
			options->setHeader(Options::OPTION_ISO,isoCheck->isChecked());
		}
	
		//mode
		if(options->getFormat()==mp3) {
			QString mode=modeCombo->currentText();
			if(mode=="Mono")
				options->setMode(mono);
			if(mode=="Joint stereo")
				options->setMode(joint);
			if(mode=="Stereo")
				options->setMode(stereo);
			if(mode=="Force")
				options->setMode(force);
		}
		
		//misc
		options->setMisc(Options::OPTION_DOWNMIX,downmixCheck->isChecked());
		options->setMisc(Options::OPTION_NEW_VBR,newVbrCheck->isChecked());
		options->setMisc(Options::OPTION_TRANSFER_TAGS,transferTagsCheck->isChecked());
		
// 		options->debugPrint();
	}
		
	return ok;
}

Options * ConvertPage::getOptions( ) {
	return options;
}

void ConvertPage::selectDir() {
	QString dirName=KFileDialog::getExistingDirectory("",this,i18n("Select the output directory"));
	outputLine->setText(dirName);
}

void ConvertPage::cleanup( ) {
	QStringList tmp;
	options->setFileList(tmp);
	
	emit optionsChanged();
}

/*$SPECIALIZATION$*/


#include "convertpage.moc"

