/***************************************************************************
 *   Copyright (C) 2004 by Antonio Fasolato                                *
 *   neo@localhost                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#include "mainwidget.h"
#include "options.h"

#include <klocale.h>
#include <kmessagebox.h>

mainWidget::mainWidget(QWidget* parent, const char* name, bool modal, WFlags fl) : MainWidgetBase(parent,name, modal,fl) {
	convertPage=new ConvertPage();
	convertAdvance=new ConvertAdvance();
	lastPage=new LastPage();
	
	if(convertAdvance->initOK) {
		addPage(convertPage,i18n("Select files to convert"));
		addPage(convertAdvance,i18n("Converting"));
		addPage(lastPage,i18n("Finished"));
	
		setFinishEnabled(lastPage,true);
	
		connect(this, SIGNAL(selected(const QString &)),this,SLOT(pageShown(const QString &)));
		connect(convertAdvance, SIGNAL(workDone()),this,SLOT(finishedConverting()));
		connect(convertAdvance, SIGNAL(titleChanged(QString)),this,SLOT(updateTitlebar(QString)));
	}
}

mainWidget::~mainWidget() {
}

/*$SPECIALIZATION$*/
void mainWidget::help() {
	KMessageBox::sorry(this,i18n("<h3>No help yet!</h3><p>Not yet ready. It will be ready soon</p>"),i18n("Sorry, no help yet"));
}

void mainWidget::back() {
	if(currentPage()==convertAdvance)
		convertPage->cleanup();
	
	QWizard::back();
}

void mainWidget::next() {
	bool ok=true;
	
	if(currentPage()==convertPage) {
		ok=convertPage->readOptions();
		if(ok) {
			convertAdvance->setOptions(convertPage->getOptions());
		}
	}
	
	if(currentPage()==convertAdvance) {
		lastPage->setErrors(convertAdvance->getErrors());
	}
	
	if(ok)
		QWizard::next();
}

void mainWidget::reject() {
	bool ok=true;
	
	if(currentPage()==convertAdvance)
		ok=convertAdvance->cancel();
	else
		ok=true;
	
	if(ok)
		QWizard::reject();
}

void mainWidget::accept() {
  QWizard::accept();
}

void mainWidget::pageShown( const QString & title ) {
	if(title=="Converting" && !convertAdvance->finished) {
		setBackEnabled(convertAdvance,false);
		setNextEnabled(convertAdvance,false);
		convertAdvance->startWorking();
	}

	if(title=="Finished") {
		lastPage->showErrors();
	}
}

void mainWidget::finishedConverting( ) {
	setBackEnabled(convertAdvance,true);
	setNextEnabled(convertAdvance,true);
}

void mainWidget::updateTitlebar( QString title) {
	if(title !="")
		setCaption("klira - "+title);
	else
		setCaption("klira");
}

#include "mainwidget.moc"

