/***************************************************************************
 *   Copyright (C) 2004 by Antonio Fasolato                                *
 *   neo@localhost                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "options.h"

Options::Options(QObject *parent, const char *name)
 : QObject(parent, name), _fileList(), _sourceDir("") {
	_format=mp3;   //default value
	_bitrate=choose;  //default value
}

Options::~Options() {
}

void Options::setFormat( format f ) {
	_format=f;
}

format Options::getFormat( ) {
	return _format;
}

void Options::setInputFormat( format f ) {
	_inputFormat=f;
}

format Options::getInputFormat( ) {
	return _inputFormat;
}

void Options::setSourceDir(QString sourceDir) {
	_sourceDir=sourceDir;
}

QString Options::getSourceDir() {
	return _sourceDir;
}

void Options::debugPrint( ) {
	qDebug("Source directory: %s",_sourceDir.ascii());
	qDebug("Files to be converted:\n%s",_fileList.join("\n").ascii());
	qDebug("Output format: %d (0=mp3,1=ogg,2=wav)",_format);
	qDebug("Output bitrate: %d (0=choose,1=average,2=variable,3=preset) value: %d",_bitrate,_bitrateValue);
	qDebug("Copyright: %s",(_copyright==true?"yes":"no"));
	qDebug("Original: %s",(_original==true?"yes":"no"));
	qDebug("Error protection: %s",(_errorProtection==true?"yes":"no"));
	qDebug("ISO compliant: %s",(_iso==true?"yes":"no"));
	qDebug("Mode: %d (0=mono, 1=joint stereo, 2=stereo, 3=force)",_mode);
	qDebug("Misc options: downmix %s, new VBR  routine %s, transfer tags %s",(_downmix==true?"yes":"no"), (_newVbr==true?"yes":"no"), (_transferTags==true?"yes":"no"));
}

void Options::setFileList( QStringList fileList ) {
	_fileList=fileList;
}

QStringList Options::getFileList( ) {
	return _fileList;
}

void Options::setBitrate( bitrate b ) {
	_bitrate=b;
}

bitrate Options::getBitrate( )
{
	return _bitrate;
}

void Options::setBitrateValue( int v ) {
	_bitrateValue=v;
}

int Options::getBitrateValue( ) {
	return _bitrateValue;
}

/** Mp3 heder options
 */
const int Options::OPTION_COPYRIGHT=0;
const int Options::OPTION_ORIGINAL=1;
const int Options::OPTION_ERROR_PROTECTION=2;
const int Options::OPTION_ISO=3;

void Options::setHeader( int type, bool flag ) {
	switch(type) {
		case OPTION_COPYRIGHT:
			_copyright=flag;
			break;
		case OPTION_ORIGINAL:
			_original=flag;
			break;
		case OPTION_ERROR_PROTECTION:
			_errorProtection=flag;
			break;
		case OPTION_ISO:
			_iso=flag;
			break;
	}
}

bool Options::getHeader( int type ) {
	bool toReturn;
	switch(type) {
		case OPTION_COPYRIGHT:
			toReturn=_copyright;
			break;
		case OPTION_ORIGINAL:
			toReturn=_original;
			break;
		case OPTION_ERROR_PROTECTION:
			toReturn=_errorProtection;
			break;
		case OPTION_ISO:
			toReturn=_iso;
			break;
	}
	
	return toReturn;
}

void Options::setMode( mode m ) {
	_mode=m;
}

mode Options::getMode( ) {
	return _mode;
}

const int Options::OPTION_DOWNMIX=4;
const int Options::OPTION_NEW_VBR=5;
const int Options::OPTION_TRANSFER_TAGS=6;

void Options::setMisc( int type, bool v ) {
	switch(type) {
		case OPTION_DOWNMIX:
			_downmix=v;
			break;
		case OPTION_NEW_VBR:
			_newVbr=v;
			break;
		case OPTION_TRANSFER_TAGS:
			_transferTags=v;
			break;
	}
}

bool Options::getMisc( int type ) {
	bool toReturn;
	switch(type) {
		case OPTION_DOWNMIX:
			toReturn=_downmix;
			break;
		case OPTION_NEW_VBR:
			toReturn=_newVbr;
			break;
		case OPTION_TRANSFER_TAGS:
			toReturn=_transferTags;
			break;
	}
	return toReturn;
}

void Options::setOutputDir( QString outputDir ) {
	_outputDir=outputDir;
}

QString Options::getOutputDir( ) {
	return _outputDir;
}

#include "options.moc"
